Utilities for building stateful views
Kobold doesn’t allocate any memory on the heap for its simple components, and there is no way to update them short of the parent view re-rendering them.
However a fully functional app like that wouldn’t be very useful, as all it
could ever do is render itself once. To get around this the stateful function can
be used to create views that have ownership over some arbitrary mutable state.
Structs
- Bound
- Hook
- A hook into some state
S. A reference toHookis obtained by using thestatefulfunction. - Once
- Once
Product - Signal
- Stateful
- Stateful
Product
Enums
- Then
- An enum that implements the
ShouldRendertrait. See:
Traits
- Into
State - Trait used to create stateful components, see
statefulfor details. - Should
Render - Describes whether or not a component should be rendered after state changes. For uses see: